==> haskell-loch-th-0.2.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loch-th
version: 0.2.1
id: loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
key: loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
license: BSD3
maintainer: tomi@nomi.cz
homepage: https://github.com/liskin/loch-th
synopsis: Support for precise error locations in source files (Template Haskell version)
description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.
category: Development
author: Tomas Janousek
exposed: True
indefinite: False
exposed-modules:
    Debug.Trace.LocationTH
abi: fd24c8c4ff3709dd45cef29c4bdcb5dd
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/loch-th-0.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/loch-th-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/loch-th-0.2.1
hs-libraries: HSloch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
depends:
    base-4.10.0.0 pretty-1.1.3.3 template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             pretty-1.1.3.3=5491220463456849eb660c64bb0df8c8
             template-haskell-2.12.0.0=612ee923b47f5e11502cef08338c9f82
haddock-interfaces: /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html: /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loch-th-0.2.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loch-th
version: 0.2.1
id: loch-th-0.2.1-9VaPKnI2VxDJTG39kD8L5A
key: loch-th-0.2.1-9VaPKnI2VxDJTG39kD8L5A
license: BSD3
maintainer: tomi@nomi.cz
homepage: https://github.com/liskin/loch-th
synopsis: Support for precise error locations in source files (Template Haskell version)
description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.
category: Development
author: Tomas Janousek
exposed: True
indefinite: False
exposed-modules:
    Debug.Trace.LocationTH
abi: ea127dffc379579d400d295b1bd9062c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/loch-th-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/loch-th-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/loch-th-0.2.1
hs-libraries: HSloch-th-0.2.1-9VaPKnI2VxDJTG39kD8L5A
depends:
    base-4.10.1.0 pretty-1.1.3.3 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html: /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
